User prompt
increase the enemy spawn on the game
Code edit (2 edits merged)
Please save this source code
User prompt
add default left movement to enemy in game
User prompt
add default left movement to enemy in game
Code edit (2 edits merged)
Please save this source code
User prompt
increase the time for each bullet spawn
User prompt
if they enemy passes the player end the game
User prompt
if the enemy comes close to player end the game with game over
User prompt
remove enemybullet and its logic
User prompt
create another enemy class and spawn on the game like previous enemy class
User prompt
make enemy to shoot
User prompt
create another asset for enemy bullet and make enemy to shoot enemy bullet
User prompt
give enemy to shoot the player
Code edit (1 edits merged)
Please save this source code
User prompt
destroy the bullets if they gone beyond the player screen
User prompt
add a default right movement to the player along with the game movement
User prompt
destroy the enemy if they gone past to player
User prompt
create a asset and blend this asset with the current background
User prompt
create a new asset and assign this asset as a overlay effect for this game
User prompt
Please fix the bug: 'Uncaught TypeError: LK.effects.explosion is not a function' in or related to this line: 'LK.effects.explosion(bullet.x, bullet.y, {' Line Number: 158
User prompt
Please fix the bug: 'Uncaught TypeError: LK.effects.smoke is not a function' in or related to this line: 'LK.effects.smoke(bullet.x, bullet.y, {' Line Number: 158
User prompt
add smoke vfx in game
User prompt
how to add vfx in this game
User prompt
Please fix the bug: 'TypeError: LK.effects.smokeScreen is not a function' in or related to this line: 'LK.effects.smokeScreen(0x808080, 1000);' Line Number: 152
User prompt
add smoke effect to the whole game
/**** * Classes ****/ var Bullet = Container.expand(function () { var self = Container.call(this); var bulletGraphics = self.attachAsset('bullet', { anchorX: 0, anchorY: 0.6, scaleX: 4, scaleY: 4 }); self.speed = 5; self.update = function () { self.x += self.speed; if (self.x < 0) { self.destroy(); } }; }); var Enemy = Container.expand(function () { var self = Container.call(this); var enemyGraphics = self.attachAsset('enemy', { anchorX: 0.5, anchorY: 0.5 }); self.speed = -3; self.update = function () { self.x += self.speed; if (self.x < 0 || self.x > 2048) { self.destroy(); } }; }); var Ground = Container.expand(function () { var self = Container.call(this); var groundGraphics = self.attachAsset('ground', { anchorX: 0.5, anchorY: 0.5, scaleX: 3, // Scale horizontally by 1.2 scaleY: 3 // Scale vertically by 1.2 }); self.update = function () { // Ground moves from right to left self.x -= 5; if (self.x + self.width < 0) { self.x = 2048; } }; }); var Player = Container.expand(function () { var self = Container.call(this); var playerGraphics = self.attachAsset('player', { anchorX: 0.5, anchorY: 0.5, scaleX: 3, // Scale horizontally by 1.2 scaleY: 3 // Scale vertically by 1.2 }); self.speed = 5; self.update = function () { if (self.x < 0) { self.x = 0; } if (self.x > 300) { self.x = 300; } // Player only moves horizontally }; }); /**** * Initialize Game ****/ var game = new LK.Game(); /**** * Game Code ****/ var background1 = game.addChild(LK.getAsset('background', { anchorX: 0.5, anchorY: 0.5, x: 1024, y: 1366, width: 2048, height: 2732 })); var background2 = game.addChild(LK.getAsset('background', { anchorX: 0.5, anchorY: 0.5, x: 3072, y: 1366, width: 2048, height: 2732 })); var ground = game.addChild(new Ground()); ground.x = 1024; ground.y = 2732 - 200; // Move the ground asset a little bit up from the bottom of the screen var player = game.addChild(new Player()); player.x = 1024; player.y = ground.y - player.height; var enemies = []; var bullets = []; game.update = function () { background1.x -= 5; background2.x -= 5; if (background1.x <= -1024) { background1.x = background2.x + 2048; } if (background2.x <= -1024) { background2.x = background1.x + 2048; } if (LK.ticks % 60 == 0) { var enemy = game.addChild(new Enemy()); enemy.x = 2048; enemy.y = Math.random() * 2732; enemies.push(enemy); } for (var i = bullets.length - 1; i >= 0; i--) { var bullet = bullets[i]; if (bullet.x < player.x) { bullet.destroy(); bullets.splice(i, 1); continue; } for (var j = enemies.length - 1; j >= 0; j--) { var enemy = enemies[j]; if (bullet.intersects(enemy)) { bullet.destroy(); bullets.splice(i, 1); enemy.destroy(); enemies.splice(j, 1); break; } } } // Check if player collides with the ground asset if (player.intersects(ground) && player.y > ground.y) { // Show game over. The game will be automatically paused while game over is showing. LK.showGameOver(); // Calling this will destroy the 'Game' and reset entire game state. } }; game.down = function (x, y, obj) { var bullet = game.addChild(new Bullet()); bullet.x = player.x; bullet.y = player.y; bullets.push(bullet); // Add flash screen effect when bullet is fired LK.effects.flashScreen(0xff0000, 1000); }; game.move = function (x, y, obj) { player.y = y; };
===================================================================
--- original.js
+++ change.js
@@ -144,13 +144,10 @@
var bullet = game.addChild(new Bullet());
bullet.x = player.x;
bullet.y = player.y;
bullets.push(bullet);
- // Add explosion vfx when bullet is fired
- LK.effects.explosion(bullet.x, bullet.y, {
- scale: 0.5,
- speed: 0.5
- });
+ // Add flash screen effect when bullet is fired
+ LK.effects.flashScreen(0xff0000, 1000);
};
game.move = function (x, y, obj) {
player.y = y;
};
\ No newline at end of file
sci fi bike with person riding facing right side Single Game Texture. In-Game asset. High contrast. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows
sci fi bike with person riding facing right side Single Game Texture. In-Game asset. High contrast.
asteroid falling diffrent colors Single Game Texture. In-Game asset. High contrast. No Background